@@ -48,7 +48,7 @@ do_cmd() {
 # PYTHONPATH="`pwd`/lib/python" python ./test_util.py ...
 script="tests/testarea/test_normalization.py"
 cat > $script << EOM
-#!/usr/bin/python
+#! /usr/bin/env $interpreter
 
 import sys
 import ufw.util
@@ -207,6 +207,10 @@ for i in $(seq 1 253); do
     fi
 done
 
+echo "TEST IPv6 short notation" >> $TESTTMP/result
+do_cmd "0" yes fe80:0000:0000:0000:0211:aaaa:bbbb:d54c fe80::211:aaaa:bbbb:d54c
+do_cmd "0" yes 2001:0db8:85a3:08d3:1319:8a2e:0370:734 2001:db8:85a3:8d3:1319:8a2e:370:734
+
 echo "TEST IPv6 CIDR" >> $TESTTMP/result
 for i in $(seq 0 127); do
     do_cmd "0" yes ::1/$i ::1/$i
@@ -222,7 +226,7 @@ do_cmd "1" no 192.168.0.1/e1 192.168.0.1/e1
 
 echo "TEST HUMAN SORTING" >> $TESTTMP/result
 cat > $script << EOM
-#!/usr/bin/python
+#! /usr/bin/env $interpreter
 
 import sys
 import ufw.util
